==> google-cloud-cpp-1.36.0.tar.gz: google-cloud-cpp-1.36.0/google/cloud/iap/README.md <==
# Cloud Identity-Aware Proxy API C++ Client Library

:construction:

This directory contains an idiomatic C++ client library for the
[Cloud Identity-Aware Proxy API][cloud-service-docs], a service to control
access to applications running on Google Cloud Platform.

This library is **experimental**. Its APIs are subject to change without notice.

Please note that the Google Cloud C++ client libraries do **not** follow
[Semantic Versioning](https://semver.org/).

## Supported Platforms

* Windows, macOS, Linux
* C++11 (and higher) compilers (we test with GCC >= 5.4, Clang >= 6.0, and
  MSVC >= 2017)
* Environments with or without exceptions
* Bazel and CMake builds

## Documentation

* Official documentation about the [Cloud Identity-Aware Proxy API][cloud-service-docs] service
* [Reference doxygen documentation][doxygen-link] for each release of this
  client library
* Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/iap
[doxygen-link]: https://googleapis.dev/cpp/google-cloud-iap/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/iap

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

<!-- inject-quickstart-start -->
```cc
#include "google/cloud/iap/identity_aware_proxy_o_auth_client.h"
#include "google/cloud/project.h"
#include <iostream>
#include <stdexcept>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace iap = ::google::cloud::iap;
  auto client = iap::IdentityAwareProxyOAuthServiceClient(
      iap::MakeIdentityAwareProxyOAuthServiceConnection());

  google::cloud::iap::v1::ListBrandsRequest request;
  request.set_parent(google::cloud::Project(argv[1]).FullName());
  // ListBrands is not paginated, a single response includes all the "brands".
  auto response = client.ListBrands(request);
  if (!response) throw std::runtime_error(response.status().message());
  std::cout << response->DebugString() << "\n";

  return 0;
} catch (std::exception const& ex) {
  std::cerr << "Standard exception raised: " << ex.what() << "\n";
  return 1;
}
```
<!-- inject-quickstart-end -->

* Packaging maintainers or developers who prefer to install the library in a
  fixed directory (such as `/usr/local` or `/opt`) should consult the
  [packaging guide](/doc/packaging.md).
* Developers wanting to use the libraries as part of a larger CMake or Bazel
  project should consult the [quickstart guides](#quickstart) for the library
  or libraries they want to use.
* Developers wanting to compile the library just to run some of the examples or
  tests should read the current document.
* Contributors and developers to `google-cloud-cpp` should consult the guide to
  [setup a development workstation][howto-setup-dev-workstation].

[howto-setup-dev-workstation]: /doc/contributor/howto-guide-setup-development-workstation.md

## Contributing changes

See [`CONTRIBUTING.md`](../../../CONTRIBUTING.md) for details on how to
contribute to this project, including how to build and test your changes
as well as how to properly format your code.

## Licensing

Apache 2.0; see [`LICENSE`](../../../LICENSE) for details.

==> google-cloud-cpp-2.30.0.tar.gz: google-cloud-cpp-2.30.0/google/cloud/iap/README.md <==
# Cloud Identity-Aware Proxy API C++ Client Library

This directory contains an idiomatic C++ client library for the
[Cloud Identity-Aware Proxy API][cloud-service-docs], a service to control
access to applications running on Google Cloud Platform.

While this library is **GA**, please note that the Google Cloud C++ client
libraries do **not** follow [Semantic Versioning](https://semver.org/).

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

For detailed instructions on how to build and install this library, see the
top-level [README](/README.md#building-and-installing).

<!-- inject-quickstart-start -->

```cc
#include "google/cloud/iap/v1/identity_aware_proxy_o_auth_client.h"
#include "google/cloud/project.h"
#include <iostream>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace iap = ::google::cloud::iap_v1;
  auto client = iap::IdentityAwareProxyOAuthServiceClient(
      iap::MakeIdentityAwareProxyOAuthServiceConnection());

  google::cloud::iap::v1::ListBrandsRequest request;
  request.set_parent(google::cloud::Project(argv[1]).FullName());
  // ListBrands is not paginated, a single response includes all the "brands".
  auto response = client.ListBrands(request);
  if (!response) throw std::move(response).status();
  std::cout << response->DebugString() << "\n";

  return 0;
} catch (google::cloud::Status const& status) {
  std::cerr << "google::cloud::Status thrown: " << status << "\n";
  return 1;
}
```

<!-- inject-quickstart-end -->

## More Information

- Official documentation about the
  [Cloud Identity-Aware Proxy API][cloud-service-docs] service
- [Reference doxygen documentation][doxygen-link] for each release of this
  client library
- Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/iap
[doxygen-link]: https://cloud.google.com/cpp/docs/reference/iap/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/iap
